@@ -4,8 +4,10 @@ BERTLexSub,
 EmbeddingLookup,
 WordNetRaw
 )
-from .process_data import(
+from .process_data import (
 Candidate,
 Indexer,
-CustomTokenizer
+CustomTokenizer,
+DataReader,
+LexSubExample
 )
