@@ -1,4 +1,4 @@
 from .custom_utils import LexSubUtils
 from .bert_mask_lm import BERTLexSub
-from .word_embedding_models import EmbeddingLookup
+from .embedding_utils import EmbeddingLookup
 from .wordnet_models import WordNetRaw
