@@ -1,5 +1,4 @@
-from lexsub import LexSubExample
-from lexsub import EmbeddingLookup
+from lexsub import EmbeddingLookup, LexSubExample
 
 
 class DataReader:
